//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.awt.Component;

import javax.swing.JOptionPane;
import javax.swing.JTable;

/** Dialog for setting association between colours and frequency levels. */
public class ColourDialogue
{
	/** Table displaying the colour information. */
	private JTable table;
	
	/** The model for the table. */
	private ColourTable model;
	
	/** Items displayed in the dialogue */
	private Object[] items;
	
	/** Table cell rendered showing the colours. */
	private ColouredRenderer renderer;
	
	/** Action object that causes a refresh. */
	private Refresher refresher;
	
	/** Create a colour dialogue.
	 *  
	 * @param rows Number of rows.
	 * @param renderer Table cell renderer.
	 * @param refresher Refresher called after an action.
	 */
	public ColourDialogue(int rows, ColouredRenderer renderer, Refresher refresher)
	{
		model = new ColourTable(rows);
		table = new JTable(model);
		items = new Object[2];
		items[0] = table.getTableHeader();
		items[1] = table;
		
		this.renderer  = renderer;
		this.refresher = refresher;

		//Set up renderer and editor for the Favorite Color column.
		ColourTable.setUpColorRenderer(table);
		ColourTable.setUpColourEditor(table);
	}
	
	/** Show the dialogue.
	 *  
	 * @param parent Parent component
	 */
	public void show(Component parent)
	{
		model.set(renderer.getLevels(), renderer.getColours());
		
		if (JOptionPane.showConfirmDialog(parent, items,
			 "Choose colour settings", JOptionPane.OK_CANCEL_OPTION)
			 == JOptionPane.OK_OPTION)
		 {
		 	renderer.assignColours(model.getLevels(), model.getColours());
			
			if (refresher != null)
			{
				refresher.refresh(0);
			}
		 }
	}
}
