//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.io.File;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

/** Action to delete the selected file. */
public class DeleteAction extends AbstractAction
{
	/** File lister. */
    private Lister lister;
    
    /** Refresh coordiator */
    private Refresher refresher;
    
    /** True to require confirmation. */
    private boolean confirm;
    
    /** Create the move action
     * 
     * @param l File lister
     * @param r Refresh coordinator
     */
    public DeleteAction(Lister l, Refresher r)
    {
        super();
        lister = l;
        refresher = r;
        confirm = true;
    }
    
	/** Set confirmation requirement.
	 *  @param confirm True if confirmation is required.
	 */
	public void setConfirm(boolean confirm)
	{
		this.confirm = confirm;
	}
    
	/** Get confirmation requirement.
	 *  @return confirm True if confirmation is required.
	 */
	public boolean getConfirm()
	{
		return confirm;
	}
    
    /** Perform the action
     * @param e Action event
     */
    public void actionPerformed(ActionEvent e)
    {
        File src = lister.getSelected();
        if (src != null)
        {
        	if (confirm)
        	{
				int ret = JOptionPane.showConfirmDialog(null, 
				"Really delete "+src.getAbsolutePath()+"?",
				"Confirm deletion", 
				JOptionPane.YES_NO_OPTION);
				if (ret != JOptionPane.YES_OPTION)
				{
					return;
				}
        	}
        	
        	boolean success = src.delete();
            if (!success)
            {
                JOptionPane.showMessageDialog
                (null, "Delete failed", "Didn't do it",
                 JOptionPane.ERROR_MESSAGE);
            }
            else
            {
            	refresher.refresh(0);
            }
        }
        else
        {
            Toolkit.getDefaultToolkit().beep();
        }
    }
}
    


