//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.io.File;

import javax.swing.tree.DefaultMutableTreeNode;

/** A node of an file explorer */
public class ExplorerNode extends DefaultMutableTreeNode
{
	/** Has this node been populated (expanded)? */
    private boolean populated = false;
    
    /** File associated with the node. */
    private File file;
    
    /** Name for the dummy root. */
    private static final String rootString = "^";

	/** Create a node on a given file.
	 * 
	 * @param file File for the node.
	 */
    public ExplorerNode(File file)
    {
		super();
		this.file = file;
    }

	/** Create an empty node
	 */
    public ExplorerNode()
    {
		super();
		file = null;
    }

	/** Get a name for the node
	 * 
	 * @return name of the node. Special string for the root.
	 */
    public String toString()
    {
		// special case for root of tree
		if (file == null)
		{
	    	return rootString;
		}
		else
		{
		    String name = (file.getParent() == null) ? file.getPath() : file.getName();
		    return (name == null || name.equals("")) ? "?" : name;
		}
    }
   
    /** Get the file object associated with this directory/node
     * @return file for the node.
     */
    public File getFile()
    {
		return file;
    }

    /** See if populated.
     * 
     * @return true if populated.
     */
    public boolean isPopulated()
    {
		return populated;
    }

	/** Set populated flag
	 * 
	 * @param p Populated flag
	 */
    public void setPopulated(boolean p)
    {
		populated = p;
    }
}
