//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.io.File;
import java.util.Enumeration;
import java.util.Properties;

import javax.swing.BorderFactory;
import javax.swing.JTree;
import javax.swing.border.Border;
import javax.swing.tree.TreePath;

/** Explorer tree.
 *  The code here was very loosely based on the file system tree in jV
 *  (www.flat222.org), but has ended up somewhat different.
 */
public class ExplorerTree extends JTree implements PropertyBearing, Refreshable
{
	/** Model of the tree. */
    private ExplorerModel model;

    /** Border of the tree. */
    private Border border;

	/** Create a tree with a given model
	 * 
	 * @param m The model
	 */
    public ExplorerTree(ExplorerModel m)
    {
		super(m);
		model = m;

		border = BorderFactory.createRaisedBevelBorder();
    }
    
	/** Refresh the directory
	 * 
	 * @param dir Directory to refresh
	 */
    public void refresh(File dir)
    {
		model.refresh(dir);
    }
    
    /** Refresh the whole thing
     *  @param level Refresh level. If <=1 just refresh selected path
     */
    public void refresh(int level)
    {
    	if (level <= 1)
    	{
			TreePath path = getSelectionPath();
			if (path != null)
			{
				ExplorerNode n = (ExplorerNode) path.getLastPathComponent();
				if (n != null && n.getFile() != null)
				{
					model.refresh(n);
				}
			}
    	}
    	else
    	{
	    	model.refresh();
    	}
    }

    /** Load properties
     *  @param props Properties object
     */
    public void loadProperties(Properties props)
    {
		int max = Integer.parseInt(props.getProperty("Tree#", "0"));
		for (int i = 0; i < max; ++i)
		{
			String s = props.getProperty("Tree_"+i, null);
			if (s != null)
			{
				File f = new File(s);
				if (f.exists() && f.isDirectory())
				{
					TreePath path = model.getTreePath(f);
					expandPath(path);
				}
			}
		}
		
		String s = props.getProperty("TreeSel", null);
		if (s != null)
		{
			File f = new File(s);
			if (f.exists())
			{
				TreePath path = model.getTreePath(f);
				setSelectionPath(path);
				scrollPathToVisible(path);

			}
		}
    }

    /** Save properties
     *  @param props Properties object
     */
    public void saveProperties(Properties props)
    {
		Enumeration e = getExpandedDescendants(new TreePath(model.getRoot()));
		int max = 0;
		if (e != null)
		{
			while (e.hasMoreElements())
			{
				TreePath path = (TreePath) e.nextElement();
				ExplorerNode n = (ExplorerNode) path.getLastPathComponent();
				if (n != null && n.getFile() != null)
				{
					props.setProperty("Tree_"+max, n.getFile().toString());
					max += 1;
				}
			}
		}
		
		props.setProperty("Tree#", Integer.toString(max));
		
		TreePath path = getSelectionPath();
		if (path != null)
		{
			ExplorerNode n = (ExplorerNode) path.getLastPathComponent();
			if (n != null && n.getFile() != null)
			{
				props.setProperty("TreeSel", n.getFile().toString());
			}
		}
    }
}
