//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.io.File;
import java.io.FilenameFilter;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Properties;

/** Holder for valid extensions */
public class Extensions implements FilenameFilter, PropertyBearing
{
	/** List of extensions */
    private ArrayList exts = new ArrayList();

	/** Construct extensions object */
    public Extensions()
    {
    }
    
    /** Get number of extensions.
     *  @return number of extensions.
     */
    public int size()
    {
    	return exts.size();
    }

	/** Add extension to the known list.
	 * 
	 * @param ext Extension to add
	 */
    public void add(String ext)
    {
        exts.add(ext.toLowerCase());
    }

	/** Test if a file is accepted by checking its extension.
	 *  All files are accepted if no extensions have been registered.
	 *  @param dir Directory containing the file.
	 *  @param name Name of the file.
	 *  @return True if file has a valid extensions.
	 */
    public boolean accept(File dir, String name)
    {
        if (exts.size() == 0)
        {
            return true;
        }

        String n = name.toLowerCase();
        for (Iterator e = exts.iterator(); e.hasNext(); )
        {
            if (n.endsWith((String) e.next()))
            {
                return true;
            }                
        }

        return false;
    }

    /** Load properties.
     *  @param props Properties object.
     */
    public void loadProperties(Properties props)
    {
		int max = Integer.parseInt(props.getProperty("Extensions#", "0"));
		if (max > 0)
		{
			exts.clear();
		}
		for (int i = 0; i < max; ++i)
		{
			String s = props.getProperty("Extension_"+i, null);
			if (s != null)
			{
				exts.add(s);
			}
		}        
    }

    /** Save properties.
     * @param props Properties object
     */
    public void saveProperties(Properties props)
    {
		int max = exts.size();
		props.setProperty("Extensions#", Integer.toString(max));
    	
		int c = 0;
		for (Iterator i = exts.iterator(); i.hasNext(); ++c)
		{
			props.setProperty("Extension_"+c, i.next().toString());
		}
    }
}

