//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.io.File;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

/** Action which moves the file selected in a lister to the directory specified
 * in given row of the paths table. A key selects the row.
 * Undo information is recorded.
 */
public class MoveAction extends AbstractAction
{
	/** Code for the key */
    private int key;
    
    /** Table of paths */
    private PathsTable paths;
    
    /** File lister */
    private Lister lister;
    
    /** Refresh coordinator */
    private Refresher refresher;
    
    /** Undo action object */
    private UndoMoveAction undo;
    
    /** Create the move action
     * 
     * @param k Key which causes the action
     * @param p Table of paths
     * @param l File lister
     * @param u Undo object
     * @param r Refresh coordinator
     */
    public MoveAction(int k, PathsTable p, Lister l, UndoMoveAction u, Refresher r)
    {
        super();
        key   = k;
        paths = p;
        lister = l;
        undo = u;
        refresher = r;
    }
    
    /** Perform the action: moves the file.
     * @param e Even object.
     */
    public void actionPerformed(ActionEvent e)
    {
        File dest = paths.getPath(key);
        File src  = lister.getSelected();
        if (dest != null && src != null && dest.exists() && dest.isDirectory())
        {
            File target = new File(dest, src.getName());
            if (target != src)
            {
            	if (target.exists())
            	{
            		if (JOptionPane.showConfirmDialog(null,
            			 "File "+target.toString()+" exists. Try to overwrite it?",
            			 "Overwrite file", JOptionPane.YES_NO_OPTION)
            			 != JOptionPane.YES_OPTION)
            		{
            			return;
            		}
            		
            		if (!target.delete())
            		{
						JOptionPane.showMessageDialog
						(null, "File delete failed for "+target.toString(), "Didn't do it",
						 JOptionPane.ERROR_MESSAGE);
						return;
            		}
            	}
            	
            	undo.setValues(null, null);
                boolean success = src.renameTo(target);
                if (!success)
                {
                    JOptionPane.showMessageDialog
                    (null, "File move failed from "+src.toString()+" to "+target.toString(), "Didn't do it",
                     JOptionPane.ERROR_MESSAGE);
                }
                else
                {
					undo.setValues(src, target);
                	refresher.refresh(0);
                }
            }
            else
            {
                Toolkit.getDefaultToolkit().beep();
            }            
        }
        else
        {
            Toolkit.getDefaultToolkit().beep();
        }
    }
}
    


