/*
 * <copyright>
 * Copyright  2000-2004, David Elworthy.
 * </copyright>
 *
 * $Header: $
 * Title:        PasswordManager
 * Created:      Feb 19, 2005
 * Description:  Password manager
 */

package com.friendlymoose.feast;

import java.util.Properties;

/** Manages password access.
 */
public class PasswordManager implements PropertyBearing
{
    /** The encoded password. May be null. */
    private String password;
    
    /** Construct a password manager.
     */
    public PasswordManager()
    {
    }

    /** Load properties.
     *  @param props Properties object.
     */
    public void loadProperties(Properties props)
    {
        password = props.getProperty("Password");
    }

    /** Save properties
     *  @param props Properties object.
     */
    public void saveProperties(Properties props)
    {
        if (password != null)
        {
            props.setProperty("Password", password);
        }
    }
    
    /** Validate the password.
     *  Checks that the password stored in the class decrypts to the argument.
     *  @param pCrypter Encrypter/decrypter.
     *  @param pPassword Plain text password.
     *  @return True if password is OK. Always true if no password is set. Always false if there is
     *  an exception while decrypting.
     */
    public boolean isOK(Crypter pCrypter, String pPassword)
    {
        try
        {
            return (password == null) ? true : pCrypter.validate(password, pPassword);
        }
        catch (Exception e)
        {
            return false;
        }
    }
    
    /** Set the password.
     *  @param pCrypter Encrypter/decrypter.
     *  @param pPassword New password. null removes password
     *  @throws Exception if the password could not be set.
     */
    public void setPassword(Crypter pCrypter, String pPassword) throws Exception
    {
        password = (pPassword == null) ? null : pCrypter.crypt(pPassword, false);
    }
    
    /** Report if there is a password.
     *  @return True if there is a password
     */
    public boolean hasPassword()
    {
        return (password != null);
    }
}
