//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Properties;

/** Hold properties and the objects which use them.
 */
public class PropertyHolder
{
	/** The property bearers */
	private ArrayList bearers = new ArrayList();
	
	/** Construct property holder. */
	public PropertyHolder()
	{
	}
	
	/** Load and apply properties.
	 * 
	 * @param from File to load them from. It is in the standard Java properties format.
	 */
	public void load(File from)
	{
		Properties props = new Properties();
		try
		{
			FileInputStream stream = new FileInputStream(from); 
			props.load(stream);
			stream.close();
		}
		catch (Exception e)
		{
		}
			
		for (Iterator i = bearers.iterator(); i.hasNext(); )
		{
			((PropertyBearing) i.next()).loadProperties(props);
		}
	}

	/** Gather properties values from objects and save properties.
	 * 
	 * @param to File to save properties to
	 * @param title Title for the properties
	 */
	public void save(File to, String title)
	{
		try
		{
			Properties props = new Properties();
			for (Iterator i = bearers.iterator(); i.hasNext(); )
			{
				((PropertyBearing) i.next()).saveProperties(props);
			}
				
			props.store(new FileOutputStream(to), title);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}
	
	/** Add a property bearer.
	 * 
	 * @param bearer Object to add to the list. It will be included on load and
	 * save calls.
	 */
	public void add(PropertyBearing bearer)
	{
		bearers.add(bearer);
	}
}
