//A component of FEAST.
//Copyright (c) 2003 David Elworthy.
//For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.File;

import javax.swing.JPopupMenu;
import javax.swing.tree.TreePath;

/** Adjuster - on right click allows a path to be assigned to a key */
public class TreeAdjuster extends MouseAdapter
{
	/** The file explorer tree */
    private ExplorerTree tree;

	/** The menu which is popped up */
    private JPopupMenu menu;
    
    /** The path which was selected. */
    private TreePath path;

	/** An assign action used when we get a shift click. */
	private AssignAction assign;
	
	/** Create an adjuster linking an explorer tree and a menu
	 * @param t The explorer tree
	 * @param m A menu to pop up on a mouse action
	 * @param p The paths table; needed so we can construct an assign action
	 * used when we get a shift click.
	 * @param l The lister; needed so we can construct an assign action
	 * used when we get a shift click.
	 */
    public TreeAdjuster(ExplorerTree t, JPopupMenu m, PathsTable p, Lister l)
    {
        tree   = t;
        menu   = m;
        assign = new AssignAction(-1, p, this, l);
    }
    
    /** Get the path which was last chosen.
     * @return Chosen path.
     */
    public TreePath getPath()
    {
        return path;
    }

    /** Get file for the current node.
     *  @return The file for the currently selected node, or null if none.
     */
    public File getFile()
    {
        TreePath p = getPath();
        String path = "";
        if (p != null)
        {
            ExplorerNode node = (ExplorerNode) p.getLastPathComponent();   
            path = node.getFile().getAbsolutePath();
        }
        
        return (path == null || path.length() == 0) ? null : new File(path);
    }
    
    /** Respond to mouse click. Shows the menu.
     * @param event The event.
     */
    public void mouseClicked(MouseEvent event)
    {
        path = null;
        try
        {
            if ((event.getModifiers() & MouseEvent.BUTTON3_MASK) != 0)
            {
                int xCoord = event.getX();
                int yCoord = event.getY();

                path = tree.getPathForLocation(xCoord, yCoord);
				if (path != null)
				{
	                if ((event.getModifiers() & MouseEvent.SHIFT_MASK) != 0)
    	            {
        	        	// Do a simulated assign action
	                	assign.actionPerformed(null);
    	            }
    	            else
	                {
	                    menu.show(tree, xCoord, yCoord);
	                }
				}
            }
        }
        catch(Exception x)
        {}
    }
}