// A component of FEAST.
// Copyright (c) 2003 David Elworthy.
// For information, visit www.friendlymoose.com
package com.friendlymoose.feast;
import java.awt.event.ActionEvent;
import java.io.File;
import java.util.LinkedList;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

/** Action which undoes a file move action. Retains several levels of undo. */
public class UndoMoveAction extends AbstractAction
{
	/** File lister. */
    private Lister lister;
    
    /** Refresh coordinator. */
    private Refresher refresher;
    
    /** Last of last sources. */
    private LinkedList lastSource;
    
    /** List of last targets. */
    private LinkedList lastTarget;
    
    /** Maximum list size */
    private int max;
    
    /** Create an undo move action
     * 
     * @param size Size of undo history
     * @param l Lister for files
     * @param r Refresh coordinator
     */
    public UndoMoveAction(int size, Lister l, Refresher r)
    {
        super();
        lister = l;
        refresher = r;
        lastSource = new LinkedList();
        lastTarget = new LinkedList();
        max = size;
    }
    
    /** Record a move.
     * 
     * @param src Source of the move
     * @param target Target of the move
     */
    public void setValues(File src, File target)
    {
    	if (src == null || target == null)
    	{
    		return;
    	}
    		
    	if (lastSource.size() == max)
    	{
    		lastSource.removeFirst();
    		lastTarget.removeFirst();
    	}
    	
    	lastSource.add(src);
    	lastTarget.add(target);
    }
    
    /** Action handler - undoes the most recent move.
     *  @param e Action event.
     */
    public void actionPerformed(ActionEvent e)
    {
    	if (lastSource.size() == 0)
    	{
    		JOptionPane.showMessageDialog(null, "Undo not available");
    	}
    	else
    	{
			File src    = (File) lastSource.removeLast();
			File target = (File) lastTarget.removeLast();

    		int reply = JOptionPane.showConfirmDialog(null, "Undo move of "
    		         +src.toString()+" to "+target.toString()+"?", "Undo",
    		          JOptionPane.YES_NO_OPTION );
    		
    		if (reply == JOptionPane.YES_OPTION)
    		{
				boolean success = target.renameTo(src);
				if (!success)
				{
					JOptionPane.showMessageDialog
					(null, "File move failed from "+target.toString()+" to "+src.toString(), "Didn't do it",
					 JOptionPane.ERROR_MESSAGE);
				}
				else
				{
					refresher.refresh(0);
					lister.setSelected(src, Lister.NOINDEX);
					lister.requestFocus();
				}
    		}
    	}
    }
}
